==> igniteui-react-charts-18.5.1.tgz: package/esm2015/lib/ChaikinVolatilityIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { ChaikinVolatilityIndicatorStrategy } from "./ChaikinVolatilityIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let ChaikinVolatilityIndicator = /*@__PURE__*/ (() => {
    class ChaikinVolatilityIndicator extends StrategyBasedIndicator {
        bg() {
            return new ChaikinVolatilityIndicator();
        }
        get_yz() {
            return new ChaikinVolatilityIndicatorStrategy();
        }
        get yz() {
            return this.get_yz();
        }
        get_zc() {
            return ChaikinVolatilityIndicator.$;
        }
        get zc() {
            return this.get_zc();
        }
        get zk() {
            return typeGetValue(this.c(ChaikinVolatilityIndicator.zl));
        }
        set zk(a) {
            this.h(ChaikinVolatilityIndicator.zl, a);
        }
        y5() {
            return this.zk;
        }
        ze(a) {
            this.zk = a;
        }
    }
    ChaikinVolatilityIndicator.$t = /*@__PURE__*/ markType(ChaikinVolatilityIndicator, 'ChaikinVolatilityIndicator', StrategyBasedIndicator.$);
    ChaikinVolatilityIndicator.zl = /*@__PURE__*/ StrategyBasedIndicator.zh(10, ChaikinVolatilityIndicator.$);
    return ChaikinVolatilityIndicator;
})();

==> igniteui-react-charts-18.6.0.tgz: package/esm2015/lib/ChaikinVolatilityIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { ChaikinVolatilityIndicatorStrategy } from "./ChaikinVolatilityIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let ChaikinVolatilityIndicator = /*@__PURE__*/ (() => {
    class ChaikinVolatilityIndicator extends StrategyBasedIndicator {
        bc() {
            return new ChaikinVolatilityIndicator();
        }
        get_y0() {
            return new ChaikinVolatilityIndicatorStrategy();
        }
        get y0() {
            return this.get_y0();
        }
        get_zd() {
            return ChaikinVolatilityIndicator.$;
        }
        get zd() {
            return this.get_zd();
        }
        get zl() {
            return typeGetValue(this.c(ChaikinVolatilityIndicator.zm));
        }
        set zl(a) {
            this.h(ChaikinVolatilityIndicator.zm, a);
        }
        y6() {
            return this.zl;
        }
        zf(a) {
            this.zl = a;
        }
    }
    ChaikinVolatilityIndicator.$t = /*@__PURE__*/ markType(ChaikinVolatilityIndicator, 'ChaikinVolatilityIndicator', StrategyBasedIndicator.$);
    ChaikinVolatilityIndicator.zm = /*@__PURE__*/ StrategyBasedIndicator.zi(10, ChaikinVolatilityIndicator.$);
    return ChaikinVolatilityIndicator;
})();
